"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const generator_1 = __importDefault(require("@babel/generator"));
const path_1 = require("path");
const util_1 = require("util");
const xml_parser_1 = require("./xml-parser");
function loader(content, map) {
    const callback = this.async();
    loadContent(this, content).then((output) => {
        callback(null, output, map);
    }).catch((err) => {
        callback(err);
    });
}
exports.default = loader;
async function loadContent(loader, content) {
    const options = loader.getOptions();
    const moduleRelativePath = (0, path_1.relative)(options.appPath, loader.resourcePath);
    const { output, pathsToResolve } = (0, xml_parser_1.convertDocumentToAST)(content, {
        moduleRelativePath,
        platform: options.platform,
        attributeValueFormatter: options.preprocess?.attributeValueFormatter
    });
    if (output == null) {
        return '';
    }
    // XML parser does not work asynchronously, so we resolve requested modules once everything is done
    if (pathsToResolve?.length) {
        const resolveAsync = (0, util_1.promisify)(loader.resolve);
        await Promise.all(pathsToResolve.map(request => resolveAsync(loader.context, request)));
    }
    // Convert AST to JS
    return options.preprocess?.transformAst ? options.preprocess?.transformAst(output, generator_1.default) : (0, generator_1.default)(output).code;
}
//# sourceMappingURL=index.js.map